@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::ARODLAND;
 # ABSTRACT: Use L<Dist::Zilla> like ARODLAND does
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 use 5.10.0;
 use Moose;
@@ -35,7 +35,8 @@ sub bundle_config {
   my $repository_web = $config->{repository_web};
 
   my $no_a_pre = $config->{no_AutoPrereqs} // 0;
-  my $no_makemaker = $config->{no_MakeMaker} // 0;
+  my $install_plugin = $config->{install_plugin} // "mbtiny";
+  $install_plugin = lc $install_plugin;
   my $nextrelease_format = $config->{nextrelease_format} // "Version %v: %{yyyy-MM-dd}d";
 
   my $nextversion = $config->{nextversion} // "git"; # git, autoversion, manual
@@ -84,7 +85,7 @@ sub bundle_config {
       payload => { },
   });
 
-  if ($no_makemaker) {
+  if ($install_plugin ne 'makemaker') {
     @plugins = grep { $_->[1] ne 'Dist::Zilla::Plugin::MakeMaker' } @plugins;
   }
 
@@ -147,9 +148,16 @@ sub bundle_config {
     ],
     [
       GatherDir => {
-        exclude_filename => 'README'
       }
     ],
+    ($install_plugin eq 'modulebuild_optionalxs'
+      ? ([ 'ModuleBuild::OptionalXS' => [] ])
+      : ()
+    ),
+    ($install_plugin eq 'mbtiny'
+      ? ([ 'ModuleBuildTiny' => [] ])
+      : ()
+    ),
 #    [ CheckChangesHasContent => { } ],
   );
 
@@ -212,7 +220,7 @@ Dist::Zilla::PluginBundle::ARODLAND - Use L<Dist::Zilla> like ARODLAND does
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
@@ -276,6 +284,12 @@ It's equvalent to
     
     [AutoVersion] ;; if nextversion is set to 'autoversion'
 
+    [ModuleBuildTiny] ;; by default
+
+    [MakeMaker] ;; if install_plugin is 'makemaker'
+
+    [ModuleBuild::OptionalXS] ;; if install_plugin is 'modulebuild_optionalxs'
+
     [@Git]
     allow_dirty = dist.ini
     allow_dirty = README
@@ -290,7 +304,7 @@ Andrew Rodland <arodland@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Andrew Rodland.
+This software is copyright (c) 2017 by Andrew Rodland.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
